@@ -1,22 +1,64 @@
+#!/usr/bin/env python
+__author__ = "Tom Fu"
+
+__version__ = "3.0"
+
 import pandas as pd
 import summarizePathwayHierarchy as summarizer
 from mergeDatabases import MergeDatabase
+import time
 import os
+import sys
+import argparse
+from argparse import RawTextHelpFormatter
 
 
 class EnrichmentPreprocess:
-    def __init__(self, outputRoot):
+    def __init__(self, outputRoot, multiEn='', goSlims='', goXml=''):
         self.outputRoot = outputRoot
+        self.multiEn = multiEn
+        self.goSlims = goSlims
+        self.goXml = goXml
         self.enrichmentFileNameL = []
         self.enrichmentsL = [[]]
 
-    def splitFilesAndRunSummary(self, source, ontologyFile, xmlFile, runAncAndDes=False, deleteTempCSV=True):
+    @staticmethod
+    def processArguments():
+        parser = argparse.ArgumentParser(description="""\
+Utility %s version %s.
+
+* Script1: enrichment.py
+    * Input outputRoot
+    * Input path to the multiEnrichment file
+    * Input go-basic.obo
+    * Input GO_BP.xml
+    * Output: summarization for multienrichment input
+
+""" % (os.path.basename(sys.argv[0]), __version__), formatter_class=RawTextHelpFormatter)
+        parser.add_argument('-o', '--outputRoot',
+                            help='root of the output files', required=True)
+        parser.add_argument(
+            '-m', '--multiEn', help='csv/txt format multiple enrichment file path', required=True)
+        parser.add_argument(
+            '-g', '--goSlims',   help='gene ontology basic go slims path',  required=True)
+        parser.add_argument(
+            '-x', '--goXml', help='XML version of the MSigDB GOBP path', required=True)
+        try:
+            args = parser.parse_args()
+        except:
+            args = None
+        return args
+
+    def splitFilesAndRunSummary(self, runAncAndDes=False, deleteTempCSV=True):
         '''Method for splitting one file containing multiple columns to form multiple pandas dfs to be run the summary on each one'''
+        source = self.multiEn
         if runAncAndDes == False:
             # Assumes that the two files exist
             ancestorFileName = self.outputRoot + ".pathway_to_go_id_ancestors.xls"
             descendantFileName = self.outputRoot + ".term_classes_to_pathways.xls"
         else:
+            # next line assumes that the user inputs something
+            ontologyFile, xmlFile = self.goSlims, self.goXml
             md = MergeDatabase(ontologyFile, xmlFile,
                                'enrichmentPlaceholder', self.outputRoot)
             md.generateAncAndDecOnly()
@@ -169,3 +211,26 @@ class EnrichmentPreprocess:
             extendedAdditionalEnrichments.append(
                 [pathway for pathway in currentEnrichedPathwaysGO if pathway not in extendedAdditionalEnrichments])
         return allEnrichmentsL, extendedAdditionalEnrichments
+
+
+########################################################################################
+# MAIN
+########################################################################################
+
+# Process command line options
+# Instantiate analyzer using the program arguments
+# Analyze this !
+
+if __name__ == '__main__':
+    try:
+        sys.stderr.write("Command line %s\n" % " ".join(sys.argv))
+        myArgs = EnrichmentPreprocess.processArguments()
+        if (myArgs is None):
+            pass
+        else:
+            bp = EnrichmentPreprocess(
+                outputRoot=myArgs.outputRoot, multiEn=myArgs.multiEn, goSlims=myArgs.goSlims, goXml=myArgs.goXml)
+            bp.splitFilesAndRunSummary(runAncAndDes=True, deleteTempCSV=False)
+    except:
+        sys.stderr.write("An unknown error occurred.\n")
+        raise
