@@ -2,7 +2,7 @@
 #!/usr/bin/env python
 __author__ = "Tom Fu"
 
-__version__ = "1.0"
+__version__ = "2.0"
 
 
 import pickle
@@ -13,6 +13,10 @@ import pandas as pd
 import math
 import numpy as np
 import time
+import os
+import sys
+import argparse
+from argparse import RawTextHelpFormatter
 
 # from CCLabUtils.simpleTime import SimpleTime
 from simpleTime import SimpleTime
@@ -26,6 +30,7 @@ ENRICHMENTPERCENTS = {"1": [100], "2": [100], "3": [100],
 ENRICHCOLOR1 = "Red"
 ENRICHCOLOR2 = "Green"
 ENRICHCOLOR3 = "Blue"
+ALLENRICHMENTCOLOR = 'Purple'
 
 # ENRICHMENTCOLORS = {"1": ["Red"], "2": ["Green"], "3": ["Blue"],
 #                     "1-2": ["Red", "Green"], "1-3": ["Red", "Blue"], "2-3": ["Blue", "Green"], "1-2-3": ["Red", "Blue", "Green"]}
@@ -34,13 +39,59 @@ SUPPORTEDFORMATS = ['png', 'pdf', 'svg']
 
 
 class GOTrees():
-    def __init__(self, outputRoot, canonicalEnrichment='', displayedEnrichmentColors=[ENRICHCOLOR1, ENRICHCOLOR2, ENRICHCOLOR3]):
+    def __init__(self, outputRoot, canonicalEnrichment='', displayedEnrichmentColors=[ENRICHCOLOR1, ENRICHCOLOR2, ENRICHCOLOR3], select='legit', enrichment=1, firstEnrichmentName='enrichment 1', enrichVis='pie', outputFormat='png', numOfBackgroundEnrichments=0, allEnrichmentColor=ALLENRICHMENTCOLOR):
         self.outputRoot = outputRoot
         self.canonicalEnrichment = canonicalEnrichment
         self.ENRICHMENTCOLORS = {"1": [displayedEnrichmentColors[0]], "2": [displayedEnrichmentColors[1]], "3": [displayedEnrichmentColors[2]],
                                  "1-2": [displayedEnrichmentColors[0], displayedEnrichmentColors[1]], "1-3": [displayedEnrichmentColors[0], displayedEnrichmentColors[2]], "2-3": [displayedEnrichmentColors[1], displayedEnrichmentColors[2]], "1-2-3": [displayedEnrichmentColors[0], displayedEnrichmentColors[1], displayedEnrichmentColors[2]]}
 
         self.enrichmentsL = []
+        self.select = select
+        self.enrichment = enrichment
+        self.firstEnrichmentName = firstEnrichmentName
+        self.enrichVis = enrichVis
+        self.outputFormat = outputFormat
+        self.numOfBackgroundEnrichments = numOfBackgroundEnrichments
+        self.ALLENRICHMENTCOLOR = allEnrichmentColor
+
+    @staticmethod
+    def processArguments():
+        parser = argparse.ArgumentParser(description="""\
+Utility %s version %s.
+
+* Script1: enrichment.py
+    * Input outputRoot
+    * Input path to the multiEnrichment file
+    * Input go-basic.obo
+    * Input GO_BP.xml
+    * Output: summarization for multienrichment input
+
+""" % (os.path.basename(sys.argv[0]), __version__), formatter_class=RawTextHelpFormatter)
+        parser.add_argument('-o', '--outputRoot',
+                            help='root of the output files', required=True)
+        parser.add_argument('-c', '--canonicalEnrichment',
+                            help='the prefix after the outputRoot for the canonical enrichment, if empty just do not enter this argument', required=False)
+        parser.add_argument('-d', '--displayedEnrichmentColors', nargs='+',
+                            help='a list of up to 3 colors displayed in the pie chart/bubble chart, input format e.g.: Red Blue Green', required=False)
+        parser.add_argument(
+            '-s', '--select', help='two options for graphing - either legit and all, see documentation for more info', required=False)
+        parser.add_argument(
+            '-e', '--enrichment',   help='number of enrichmets displayed in pie charts/bubble charts (up to 3)',  required=False)
+        parser.add_argument(
+            '-f', '--firstEnrichmentName',   help='displayed name of the first enrichment, default called \'enrichment 1\'',  required=False)
+        parser.add_argument(
+            '-v', '--enrichVis',   help='type of enrichment visualization, either \'pie\' or \'sphere\', default \'pie\'',  required=False)
+        parser.add_argument(
+            '-m', '--outputFormat',   help='output format, currently supporting \'png\', \'pdf\', \'svg\', default \'png\'',  required=False)
+        parser.add_argument(
+            '-n', '--numOfBackgroundEnrichments', help='number of background enrichments, displayed as purple tips but not in pie chart or bubble chart', required=False)
+        parser.add_argument(
+            '-a', '--allEnrichmentColor', help='tip color for all nodes that are enriched, default purple', required=False)
+        try:
+            args = parser.parse_args()
+        except:
+            args = None
+        return args
 
     def selectSubTrees(self):
         """Following outputs from merger to allow users to select trees to be plotted"""
@@ -400,7 +451,7 @@ class GOTrees():
                                       position='branch-right')
                 else:
                     if str(node.name) in additionalEnrichments[0] or str(node.name) in additionalEnrichments[1] or str(node.name) in origEnrichments or str(node.name) in extendedBGAdditionalEnrichments:
-                        name_face = TextFace("▓▓▓▓▓", fgcolor="Purple",
+                        name_face = TextFace("▓▓▓▓▓", fgcolor=self.ALLENRICHMENTCOLOR,
                                              fsize=math.sqrt(int(nodeCounter))*0.001)
                         node.add_face(name_face, column=0,
                                       position='branch-right')
@@ -441,11 +492,19 @@ class GOTrees():
         tree.render(outputTreeGraphText, tree_style=ts)
         return outputTreeGraphText
 
-    def graphTreeWrapper(self, select='all', enrichment=1, firstEnrichmentName='enrichment 1', enrichVis='pie', outputFormat='png', numOfBackgroundEnrichments=0):
+    def graphTreeWrapper(self):
         '''wrapper function for tree visualization
         select: either 'all' or 'legit'
         enrichment: either 'single' or numbers (2 or 3)
         enrichVis: either 'pie' or 'sphere'''
+        # user inputs
+        select = self.select
+        enrichment = self.enrichment
+        firstEnrichmentName = self.firstEnrichmentName
+        enrichVis = self.enrichVis
+        outputFormat = self.outputFormat
+        numOfBackgroundEnrichments = self.numOfBackgroundEnrichments
+
         treeNum = 0
         # error cases
         if select not in ['all', 'legit']:
@@ -564,3 +623,44 @@ class GOTrees():
                   " printing finished, check out file " + outputTreeGraphText)
         print("Everything is done!")
         return
+
+
+########################################################################################
+# MAIN
+########################################################################################
+
+# Process command line options
+# Instantiate analyzer using the program arguments
+# Analyze this !
+if __name__ == '__main__':
+    try:
+        sys.stderr.write("Command line %s\n" % " ".join(sys.argv))
+        myArgs = GOTrees.processArguments()
+        if (myArgs is None):
+            pass
+        else:
+            print(myArgs)
+            if myArgs.canonicalEnrichment == None:
+                myArgs.canonicalEnrichment = ''
+            if myArgs.displayedEnrichmentColors == None:
+                myArgs.displayedEnrichmentColors = [
+                    ENRICHCOLOR1, ENRICHCOLOR2, ENRICHCOLOR3]
+            if myArgs.enrichment == None:
+                myArgs.enrichment = 1
+            if myArgs.firstEnrichmentName == None:
+                myArgs.firstEnrichmentName = 'enrichment 1'
+            if myArgs.enrichVis == None:
+                myArgs.enrichVis = 'pie'
+            if myArgs.outputFormat == None:
+                myArgs.outputFormat = 'png'
+            if myArgs.numOfBackgroundEnrichments == None:
+                myArgs.numOfBackgroundEnrichments = 0
+            if myArgs.allEnrichmentColor == None:
+                myArgs.allEnrichmentColor = ALLENRICHMENTCOLOR
+            print(myArgs)
+            bp = GOTrees(
+                outputRoot=myArgs.outputRoot, canonicalEnrichment=myArgs.canonicalEnrichment, displayedEnrichmentColors=myArgs.displayedEnrichmentColors, select=myArgs.select, enrichment=int(myArgs.enrichment), firstEnrichmentName=myArgs.firstEnrichmentName, enrichVis=myArgs.enrichVis, outputFormat=myArgs.outputFormat, numOfBackgroundEnrichments=int(myArgs.numOfBackgroundEnrichments), allEnrichmentColor=myArgs.allEnrichmentColor)
+            bp.graphTreeWrapper()
+    except:
+        sys.stderr.write("An unknown error occurred.\n")
+        raise
